@@ -95,7 +95,7 @@ class SimpleEnsemblingRunner(AbstractRunner):
             )
             df_ret = df_res.fillna(method='bfill').pct_change().fillna(0).copy()
             weight_normalized, last_predicted_weights = weights.weights_shift(weight_mat=weight_mat)
-            portfolio = np.cumprod(np.prod(df_ret * weight_mat.values + 1, axis=1))
+            portfolio = np.cumprod(np.prod(df_ret * weight_normalized.values + 1, axis=1))
             saver.saveResults('dd_'+savingKey, portfolio, weight_normalized,last_predicted_weights)
 
         check_ew_existence = saver.checkRunExistence('ew_'+savingKey)
@@ -103,7 +103,7 @@ class SimpleEnsemblingRunner(AbstractRunner):
             print('equally weighted')
             df_ret = df_res.fillna(method='bfill').pct_change().fillna(0).copy()
             weight_normalized, last_predicted_weights = weights.weights_shift(weight_mat=weight_mat)
-            portfolio = np.cumprod(np.prod(df_ret * weight_mat.values + 1, axis=1))
+            portfolio = np.cumprod(np.prod(df_ret * weight_normalized.values + 1, axis=1))
             saver.saveResults('ew_'+savingKey, portfolio, weight_normalized,last_predicted_weights)
 
 
@@ -124,7 +124,7 @@ class SimpleEnsemblingRunner(AbstractRunner):
             )
             df_ret = df_res.fillna(method='bfill').pct_change().fillna(0).copy()
             weight_normalized, last_predicted_weights = weights.weights_shift(weight_mat=weight_mat)
-            portfolio = np.cumprod(np.prod(df_ret * weight_mat.values + 1, axis=1))
+            portfolio = np.cumprod(np.prod(df_ret * weight_normalized.values + 1, axis=1))
             saver.saveResults('erc_'+savingKey, portfolio, weight_normalized,last_predicted_weights)
 
 
@@ -145,7 +145,7 @@ class SimpleEnsemblingRunner(AbstractRunner):
             )
             df_ret = df_res.fillna(method='bfill').pct_change().fillna(0).copy()
             weight_normalized, last_predicted_weights = weights.weights_shift(weight_mat=weight_mat)
-            portfolio = np.cumprod(np.prod(df_ret * weight_mat.values + 1, axis=1))
+            portfolio = np.cumprod(np.prod(df_ret * weight_normalized.values + 1, axis=1))
             saver.saveResults('ivp_'+savingKey, portfolio, weight_normalized,last_predicted_weights)
 
 
@@ -166,7 +166,7 @@ class SimpleEnsemblingRunner(AbstractRunner):
             )
             df_ret = df_res.fillna(method='bfill').pct_change().fillna(0).copy()
             weight_normalized, last_predicted_weights = weights.weights_shift(weight_mat=weight_mat)
-            portfolio = np.cumprod(np.prod(df_ret * weight_mat.values + 1, axis=1))
+            portfolio = np.cumprod(np.prod(df_ret * weight_normalized.values + 1, axis=1))
             saver.saveResults('mvp_'+savingKey, portfolio, weight_normalized,last_predicted_weights)
 
 
@@ -189,7 +189,7 @@ class SimpleEnsemblingRunner(AbstractRunner):
             )
             df_ret = df_res.fillna(method='bfill').pct_change().fillna(0).copy()
             weight_normalized, last_predicted_weights = weights.weights_shift(weight_mat=weight_mat)
-            portfolio = np.cumprod(np.prod(df_ret * weight_mat.values + 1, axis=1))
+            portfolio = np.cumprod(np.prod(df_ret * weight_normalized.values + 1, axis=1))
             saver.saveResults('hrp_'+savingKey, portfolio, weight_normalized,last_predicted_weights)
 
 
@@ -211,5 +211,5 @@ class SimpleEnsemblingRunner(AbstractRunner):
             )
             df_ret = df_res.fillna(method='bfill').pct_change().fillna(0).copy()
             weight_normalized, last_predicted_weights = weights.weights_shift(weight_mat=weight_mat)
-            portfolio = np.cumprod(np.prod(df_ret * weight_mat.values + 1, axis=1))
+            portfolio = np.cumprod(np.prod(df_ret * weight_normalized.values + 1, axis=1))
             saver.saveResults('mdp_'+savingKey, portfolio, weight_normalized,last_predicted_weights)
