@@ -4,8 +4,7 @@
 import sqlite3
 import pandas as pd
 
-from multiprocessing import Pool
-from napoleontoolbox.features import features_type
+from datetime import datetime
 from napoleontoolbox.file_saver import dropbox_file_saver
 
 class ParallelRunResultAnalyzer():
@@ -113,6 +112,22 @@ class ParallelRunResultAnalyzer():
         results_df = results_df.drop(['Date'], axis=1)
         return results_df
 
+    def analyzeRunWeightPredictionResult(self,run,string_date):
+        run_date = datetime.strptime(string_date, '%Y-%m-%d')
+
+        sqliteConnection = None
+        try:
+            table_name = run + '_' + run_date.strftime('%d_%b_%Y') + '_weight_prediction'
+            sqliteConnection = sqlite3.connect(self.db_path, timeout=20)
+            sqlite_select_run_query = 'SELECT * from  ' + table_name
+            results_df = pd.read_sql_query(sqlite_select_run_query, sqliteConnection)
+        except sqlite3.Error as error:
+            print("Error while creating a sqlite table", error)
+        finally:
+            if (sqliteConnection):
+                sqliteConnection.close()
+                print("sqlite connection is closed")
+        return results_df
 
     def analyzeRunRecording(self,run):
         sqliteConnection = None
