@@ -7,9 +7,11 @@
 # Built-in packages
 
 # External packages
-import numpy as np
 import math
 import pandas as pd
+from scipy.optimize import Bounds, LinearConstraint, minimize
+from napoleontoolbox.utility import metrics
+import numpy as np
 
 # Internal packages
 
@@ -525,7 +527,110 @@ def compute_sharpe(df_ret = None, weights = None, period = 252):
     print(min(weights.index))
     print('maximum weights date')
     print(max(weights.index))
-    assert df_ret.shape == df_ret.shape
+    assert df_ret.shape == weights.shape
     assert sum(weights.columns == df_ret.columns) == weights.shape[1]
     portfolio = np.cumprod(np.prod(df_ret * weights.values + 1, axis=1))
-    return sharpe(portfolio ,period = period)
\ No newline at end of file
+    return sharpe(portfolio ,period = period)
+
+
+
+
+def f_sharpe_weights_mix(w_list_, data_, w):
+    np_returns = None
+    counter = 0
+    for weights_ in w_list_:
+        if np_returns is None:
+            np_returns = w[counter] * data_.values * weights_
+        else:
+            np_returns = np_returns + w[counter] * data_.values * weights_
+        counter = counter + 1
+
+    np_returns = np_returns.sum(axis=1)
+    np_returns = np_returns[:, np.newaxis]
+    computed_sharpe = metrics.sharpe(np_returns, period=252, from_ret=True)
+    if np.isnan(computed_sharpe):
+        return 0
+    return computed_sharpe
+
+
+def find_best_sharpe(weights_list, X):
+    print(X.shape)
+    N_ = len(weights_list)
+    w0 = np.ones([N_]) / N_
+    const_sum = LinearConstraint(np.ones([1, N_]), [1], [1])
+    up_bound_ = 1.
+    low_bound_ = 0.
+    const_ind = Bounds(low_bound_ * np.ones([N_]), up_bound_ * np.ones([N_]))
+    to_optimize = lambda x: f_sharpe_weights_mix(weights_list, X, x)
+    w__ = minimize(
+        to_optimize,
+        w0,
+        method='SLSQP',
+        constraints=[const_sum],
+        bounds=const_ind
+    ).x
+    print('optimal mixing weights')
+    print(w__)
+    return w__
+
+
+def compute_average_prediction(optimal_mixing, weights_list):
+    mixed_df = None
+    counter = 0
+    for weights_ in weights_list:
+        if mixed_df is None:
+            mixed_df = optimal_mixing[counter] * weights_
+        else:
+            mixed_df = mixed_df + optimal_mixing[counter] * weights_
+        counter = counter + 1
+    return mixed_df
+
+def f_sharpe_weights_mix(w_list_, data_, w):
+    np_returns = None
+    counter = 0
+    for weights_ in w_list_:
+        if np_returns is None:
+            np_returns = w[counter] * data_.values * weights_
+        else:
+            np_returns = np_returns + w[counter] * data_.values * weights_
+        counter = counter + 1
+
+    np_returns = np_returns.sum(axis=1)
+    np_returns = np_returns[:, np.newaxis]
+    computed_sharpe = metrics.sharpe(np_returns, period=252, from_ret=True)
+    if np.isnan(computed_sharpe):
+        return 0
+    return computed_sharpe
+
+
+def find_best_sharpe(weights_list, X):
+    print(X.shape)
+    N_ = len(weights_list)
+    w0 = np.ones([N_]) / N_
+    const_sum = LinearConstraint(np.ones([1, N_]), [1], [1])
+    up_bound_ = 1.
+    low_bound_ = 0.
+    const_ind = Bounds(low_bound_ * np.ones([N_]), up_bound_ * np.ones([N_]))
+    to_optimize = lambda x: f_sharpe_weights_mix(weights_list, X, x)
+    w__ = minimize(
+        to_optimize,
+        w0,
+        method='SLSQP',
+        constraints=[const_sum],
+        bounds=const_ind
+    ).x
+    print('optimal mixing weights')
+    print(w__)
+    return w__
+
+
+def compute_average_prediction(optimal_mixing, weights_list):
+    mixed_df = None
+    counter = 0
+    for weights_ in weights_list:
+        if mixed_df is None:
+            mixed_df = optimal_mixing[counter] * weights_
+        else:
+            mixed_df = mixed_df + optimal_mixing[counter] * weights_
+        counter = counter + 1
+    return mixed_df
\ No newline at end of file
